"use strict";
// @ts-check
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = varReadOnlyDatabaseDbHandler;
const serverError_1 = __importDefault(require("./serverError"));
const parseDbResults_1 = __importDefault(require("./parseDbResults"));
const DSQL_USER_DB_HANDLER_1 = __importDefault(require("../../utils/backend/global-db/DSQL_USER_DB_HANDLER"));
const LOCAL_DB_HANDLER_1 = __importDefault(require("../../utils/backend/global-db/LOCAL_DB_HANDLER"));
/**
 * # Read Only Db Handler with Varaibles
 * @returns
 */
function varReadOnlyDatabaseDbHandler(_a) {
    return __awaiter(this, arguments, void 0, function* ({ queryString, queryValuesArray, tableSchema, }) {
        /**
         * Declare variables
         *
         * @description Declare "results" variable
         */
        let results;
        /**
         * Fetch from db
         *
         * @description Fetch data from db if no cache
         */
        try {
            results = global.DSQL_USE_LOCAL
                ? yield (0, LOCAL_DB_HANDLER_1.default)(queryString, queryValuesArray)
                : yield (0, DSQL_USER_DB_HANDLER_1.default)({
                    paradigm: "Read Only",
                    queryString,
                    queryValues: queryValuesArray,
                });
            ////////////////////////////////////////
        }
        catch ( /** @type {any} */error) {
            ////////////////////////////////////////
            (0, serverError_1.default)({
                component: "varReadOnlyDatabaseDbHandler",
                message: error.message,
                noMail: true,
            });
            /**
             * Return error
             */
            return error.message;
        }
        /**
         * Return results
         *
         * @description Return results add to cache if "req" param is passed
         */
        if (results) {
            const unparsedResults = results;
            const parsedResults = yield (0, parseDbResults_1.default)({
                unparsedResults: unparsedResults,
                tableSchema: tableSchema,
            });
            return parsedResults;
        }
        else {
            return null;
        }
    });
}
